HiveService class

Constructors

HiveService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

deleteAllData() Future<void>
Delete All the data
deleteCommonDataByDataType(List<String> dataType) Future<void>
Delete multiple commonData by dataType
getAllCommonData() Future<List?>
Retrieve all commonData
getCommonDataByDataType(String dataType) Future<Map<String, dynamic>?>
Retrieve a specific commonData by dataType
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
saveCommonData(String dataType, Map<String, dynamic> data) Future<void>
Save / Update commonData by dataType
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

commonDataBox → Box
Gets the Common box
no setter

Static Methods

initHive() Future<void>
Initializes Hive and opens boxes

Constants

commonBoxName → const String